unit uHTTPDemoMain;

interface

uses
  System.SysUtils, System.Types, System.UITypes, System.StrUtils, System.Classes, System.Variants, FMX.Types, FMX.Controls, FMX.Forms, FMX.Graphics, FMX.Dialogs, FMX.Controls.Presentation,
  FMX.StdCtrls, FMX.Memo.Types, FMX.ScrollBox, FMX.Memo, FMX.ListBox, IOUtils, uHTTPServer, FMX.Edit, FMX.EditBox, FMX.NumberBox;

type
  TfrmMain = class(TForm)
    btnStartStopTCPServer: TButton;
    btnStartStopUDPServer: TButton;
    btnTCPClientSend: TButton;
    btnUDPClientSend: TButton;
    btnHTTPClientSend: TButton;
    mBody: TMemo;
    lblBody: TLabel;
    lblTCPServerStatus: TLabel;
    lblUDPServerStatus: TLabel;
    btnStartStopHTTPServer: TButton;
    lblHTTPServerStatus: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure btnStartStopTCPServerClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure btnStartStopUDPServerClick(Sender: TObject);
    procedure btnTCPClientSendClick(Sender: TObject);
    procedure btnUDPClientSendClick(Sender: TObject);
    procedure btnStartStopHTTPServerClick(Sender: TObject);
    procedure btnHTTPClientSendClick(Sender: TObject);
  private
    { Private declarations }
    HttpServer: THttpServer;
    procedure CheckStatus;
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.fmx}

procedure TfrmMain.FormCreate(Sender: TObject);
begin
  Caption := 'HTTP Demo';
  btnTCPClientSend.Text := 'Send TCP request';
  btnUDPClientSend.Text := 'Send UDP request';
  lblBody.Text := 'HTTP response body';
  HttpServer := THttpServer.Create;
  CheckStatus;
end;

procedure TfrmMain.FormDestroy(Sender: TObject);
begin
  HttpServer.Free;
end;

procedure TfrmMain.btnHTTPClientSendClick(Sender: TObject);
begin
  mBody.Lines.AddStrings(HttpServer.SendTCPCommand(uHTTPServer.HTTPServerPort));
end;

procedure TfrmMain.btnStartStopHTTPServerClick(Sender: TObject);
begin
  if not HttpServer.IsHTTPServerActive then
    HttpServer.StartHTTPServer
  else
    HttpServer.StopHTTPServer;
  CheckStatus;
end;

procedure TfrmMain.btnStartStopTCPServerClick(Sender: TObject);
begin
  if not HttpServer.IsTCPServerActive then
    HttpServer.StartTCPServer
  else
    HttpServer.StopTCPServer;
  CheckStatus;
end;

procedure TfrmMain.btnStartStopUDPServerClick(Sender: TObject);
begin
  if not HttpServer.IsUDPServerActive then
    HttpServer.StartUDPServer
  else
    HttpServer.StopUDPServer;
  CheckStatus;
end;

procedure TfrmMain.btnTCPClientSendClick(Sender: TObject);
begin
  mBody.Lines.AddStrings(HttpServer.SendTCPCommand(uHTTPServer.TCPServerPort));
end;

procedure TfrmMain.btnUDPClientSendClick(Sender: TObject);
begin
  mBody.Lines.AddStrings(HttpServer.SendUDPCommand(uHTTPServer.UDPServerPort));
end;

procedure TfrmMain.CheckStatus;
begin
  btnStartStopTCPServer.Text := IfThen(not HttpServer.IsTCPServerActive, 'Start', 'Stop') + ' TCP Server';
  btnStartStopUDPServer.Text := IfThen(not HttpServer.IsUDPServerActive, 'Start', 'Stop') + ' UDP Server';
  btnStartStopHTTPServer.Text := IfThen(not HttpServer.IsHTTPServerActive, 'Start', 'Stop') + ' HTTP Server';
  lblTCPServerStatus.Text := 'TCP Server is ' + IfThen(HttpServer.IsTCPServerActive, 'running, port: ' + uHTTPServer.TCPServerPort.ToString, 'stopped');
  lblUDPServerStatus.Text := 'UDP Server is ' + IfThen(HttpServer.IsUDPServerActive, 'running, port: ' + uHTTPServer.UDPServerPort.ToString, 'stopped');
  lblHTTPServerStatus.Text := 'HTTP Server is ' + IfThen(HttpServer.IsHTTPServerActive, 'running, port: ' + uHTTPServer.HTTPServerPort.ToString, 'stopped');
  btnTCPClientSend.Enabled := HttpServer.IsTCPServerActive;
  btnUDPClientSend.Enabled := HttpServer.IsUDPServerActive;
  btnHTTPClientSend.Enabled := HttpServer.IsHTTPServerActive;
end;

end.
