unit uHTTPDemoMainLazarus;

interface

uses
  Types, Classes, SysUtils, Forms, Controls, Graphics, Dialogs, StdCtrls, Spin, FileUtil,
  StrUtils, uHTTPServer;

type

  { TfrmMain }

  TfrmMain = class(TForm)
    btnStartStopTCPServer: TButton;
    btnStartStopUDPServer: TButton;
    btnTCPClientSend: TButton;
    btnUDPClientSend: TButton;
    btnStartStopHTTPServer: TButton;
    btnHTTPClientSend: TButton;
    lblHTTPServerStatus: TLabel;
    lblTCPServerStatus: TLabel;
    lblUDPServerStatus: TLabel;
    lblBody: TLabel;
    mBody: TMemo;
    procedure btnHTTPClientSendClick(Sender: TObject);
    procedure btnStartStopHTTPServerClick(Sender: TObject);
    procedure btnStartStopTCPServerClick(Sender: TObject);
    procedure btnStartStopUDPServerClick(Sender: TObject);
    procedure btnTCPClientSendClick(Sender: TObject);
    procedure btnUDPClientSendClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    HttpServer: THttpServer;
    procedure CheckStatus;
  public

  end;

var
  frmMain: TfrmMain;

implementation

{$R *.lfm}

{ TfrmMain }

procedure TfrmMain.FormCreate(Sender: TObject);
begin
  Caption := 'HTTP Demo';
  btnTCPClientSend.Caption := 'Send TCP request';
  btnUDPClientSend.Caption := 'Send UDP request';
  btnHTTPClientSend.Caption := 'Send HTTP request';
  lblBody.Caption := 'HTTP response body';
  HttpServer := THttpServer.Create;
  CheckStatus;
end;

procedure TfrmMain.btnStartStopTCPServerClick(Sender: TObject);
begin
  if not HttpServer.IsTCPServerActive then
    HttpServer.StartTCPServer
  else
    HttpServer.StopTCPServer;
  CheckStatus;
end;

procedure TfrmMain.btnStartStopHTTPServerClick(Sender: TObject);
begin
  if not HttpServer.IsHTTPServerActive then
    HttpServer.StartHTTPServer
  else
    HttpServer.StopHTTPServer;
  CheckStatus;
end;

procedure TfrmMain.btnHTTPClientSendClick(Sender: TObject);
begin
  mBody.Lines.AddStrings(HttpServer.SendTCPCommand(uHTTPServer.HTTPServerPort));
end;

procedure TfrmMain.btnStartStopUDPServerClick(Sender: TObject);
begin
  if not HttpServer.IsUDPServerActive then
    HttpServer.StartUDPServer
  else
    HttpServer.StopUDPServer;
  CheckStatus;
end;

procedure TfrmMain.btnTCPClientSendClick(Sender: TObject);
begin
  mBody.Lines.AddStrings(HttpServer.SendTCPCommand(uHTTPServer.TCPServerPort));
end;

procedure TfrmMain.btnUDPClientSendClick(Sender: TObject);
begin
  mBody.Lines.AddStrings(HttpServer.SendUDPCommand(uHTTPServer.UDPServerPort));
end;

procedure TfrmMain.FormDestroy(Sender: TObject);
begin
  HttpServer.Free;
end;

procedure TfrmMain.CheckStatus;
begin
  btnStartStopTCPServer.Caption := IfThen(not HttpServer.IsTCPServerActive, 'Start', 'Stop') + ' TCP Server';
  btnStartStopUDPServer.Caption := IfThen(not HttpServer.IsUDPServerActive, 'Start', 'Stop') + ' UDP Server';
  btnStartStopHTTPServer.Caption := IfThen(not HttpServer.IsHTTPServerActive, 'Start', 'Stop') + ' HTTP Server';
  lblTCPServerStatus.Caption := 'TCP Server is ' + IfThen(HttpServer.IsTCPServerActive, 'running, port: ' + uHTTPServer.TCPServerPort.ToString, 'stopped');
  lblUDPServerStatus.Caption := 'UDP Server is ' + IfThen(HttpServer.IsUDPServerActive, 'running, port: ' + uHTTPServer.UDPServerPort.ToString, 'stopped');
  lblHTTPServerStatus.Caption := 'HTTP Server is ' + IfThen(HttpServer.IsHTTPServerActive, 'running, port: ' + uHTTPServer.HTTPServerPort.ToString, 'stopped');
  btnTCPClientSend.Enabled := HttpServer.IsTCPServerActive;
  btnUDPClientSend.Enabled := HttpServer.IsUDPServerActive;
  btnHTTPClientSend.Enabled := HttpServer.IsHTTPServerActive;
end;

end.
